Struct googapis::google::cloud::vmmigration::v1::ComputeScheduling[][src]

pub struct ComputeScheduling {
    pub on_host_maintenance: i32,
    pub restart_type: i32,
    pub node_affinities: Vec<SchedulingNodeAffinity>,
    pub min_node_cpus: i32,
}
Scheduling information for VM on maintenance/restart behaviour and node allocation in sole tenant nodes.

Fields

on_host_maintenance: i32

How the instance should behave when the host machine undergoes maintenance that may temporarily impact instance performance.

restart_type: i32

Whether the Instance should be automatically restarted whenever it is terminated by Compute Engine (not terminated by user). This configuration is identical to automaticRestart field in Compute Engine create instance under scheduling. It was changed to an enum (instead of a boolean) to match the default value in Compute Engine which is automatic restart.

node_affinities: Vec<SchedulingNodeAffinity>

A set of node affinity and anti-affinity configurations for sole tenant nodes.

min_node_cpus: i32

The minimum number of virtual CPUs this instance will consume when running on a sole-tenant node. Ignored if no node_affinites are configured.

Implementations

Returns the enum value of on_host_maintenance, or the default if the field is set to an invalid enum value.

Sets on_host_maintenance to the provided enum value.

Returns the enum value of restart_type, or the default if the field is set to an invalid enum value.

Sets restart_type to the provided enum value.